@@ -271,8 +271,8 @@ def reimage(tpu, zone, project, version, yes, dry_run, async_):
               " (Useful for killing a training session after the TPU has been recreated.)")
 @click.option('--retry', type=int, help="if the TPU creation fails (due to capacity errors or otherwise), "
                                         "retry the creation command after this many seconds")
-@click.option('--retry-randomness', type=float,  help="multiply retry time by a float between 1 and retry_randomness")
-def recreate(tpu, zone, project, version, yes, dry_run, preempted, command, retry=None, retry_randomness=1.0, **kws):
+@click.option('--retry-randomness', type=float, default=1.0, help="multiply retry time by a float between 1 and retry_randomness")
+def recreate(tpu, zone, project, version, yes, dry_run, preempted, command, retry, retry_randomness, **kws):
   """
   Recreates a TPU, optionally switching the system software to the specified TF_VERSION.
   """
